summaryrefslogtreecommitdiff
path: root/src/tile_map.h
diff options
context:
space:
mode:
authorHenry Wilson <m3henry@googlemail.com>2019-04-10 22:07:06 +0100
committerMichael Lutz <michi@icosahedron.de>2019-04-10 23:22:20 +0200
commit7c8e7c6b6e16d4a26259a676db32d8776b99817e (patch)
tree99f134b7e66367cf11e10bc5061896eab4a3264f /src/tile_map.h
parent3b4f224c0bc50e7248050d4bcbb6d83fd510c1cc (diff)
downloadopenttd-7c8e7c6b6e16d4a26259a676db32d8776b99817e.tar.xz
Codechange: Use null pointer literal instead of the NULL macro
Diffstat (limited to 'src/tile_map.h')
-rw-r--r--src/tile_map.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/tile_map.h b/src/tile_map.h
index 7a76f2b97..0cb28122d 100644
--- a/src/tile_map.h
+++ b/src/tile_map.h
@@ -267,22 +267,22 @@ static inline void SetAnimationFrame(TileIndex t, byte frame)
_me[t].m7 = frame;
}
-Slope GetTileSlope(TileIndex tile, int *h = NULL);
+Slope GetTileSlope(TileIndex tile, int *h = nullptr);
int GetTileZ(TileIndex tile);
int GetTileMaxZ(TileIndex tile);
-bool IsTileFlat(TileIndex tile, int *h = NULL);
+bool IsTileFlat(TileIndex tile, int *h = nullptr);
/**
* Return the slope of a given tile
* @param tile Tile to compute slope of
* @param h If not \c NULL, pointer to storage of z height
* @return Slope of the tile, except for the HALFTILE part
*/
static inline Slope GetTilePixelSlope(TileIndex tile, int *h)
{
Slope s = GetTileSlope(tile, h);
- if (h != NULL) *h *= TILE_HEIGHT;
+ if (h != nullptr) *h *= TILE_HEIGHT;
return s;
}
@@ -267,22 +267,22 @@ static inline void SetAnimationFrame(TileIndex t, byte frame)
* Return the slope of a given tile
* @param tile Tile to compute slope of
- * @param h If not \c NULL, pointer to storage of z height
+ * @param h If not \c nullptr, pointer to storage of z height
* @return Slope of the tile, except for the HALFTILE part
*/